{% extends "base.html" %}
{% load i18n %}
{% block title %}
    {{ site_title }} - {% trans "GCU" %}
{% endblock %}
{% block nav_bar %}

    {% include '_partials/nav_bar_section.html' %}

{% endblock %}
{% block current_context %}
{% endblock %}
{% block search_bar %}
{% endblock %}
{% block tags_selector %}
{% endblock %}
{% block content %}
    <div class="muses-list">
    </div>
{% endblock %}